import dotenv from "dotenv";
import { connectMongo } from "./database/mongo";
import { initSecrets } from "./secrets/secrets";
import { SsrServer } from "./server/impl/ssrServer";
import { checkEnvironmentVariables } from "./util/envVariables";
import { createInfisicalClient } from "./util/secrets";

// Load the environment variables
dotenv.config();

const isValid = checkEnvironmentVariables("INFISICAL_TOKEN");
if (!isValid) {
  process.exit(1);
}

export const InfisicalClient = createInfisicalClient(
  process.env.INFISICAL_TOKEN!
);

console.log("---");
console.log(
  "NOTE: If the infisical secret is invalid, it will say secrets are missing."
);
console.log("If this happens please check the env variable and/or the secret");
console.log("---");
// Load the secrets first so we ensure they are valid before starting the server
initSecrets().then(async () => {
  await connectMongo();
  console.log("Connected to mongo");

  // Init the SSR Server
  new SsrServer();
});
