/**
 * Creates the base message for web responses
 *
 * @param message the message to send
 * @returns the message
 */
function baseMessage(error: boolean, message: string) {
  return {
    error,
    message,
  };
}

/**
 * Creates an error message for web responses
 *
 * @param message the message to send
 * @returns the message
 */
function errorMessage(message: string) {
  return baseMessage(true, message);
}

/**
 * Creates a success message for web responses
 *
 * @param message the message to send
 * @returns the message
 */
function successMessage(message: string) {
  return baseMessage(false, message);
}

/**
 * Creates a message for an internal server error
 *
 * @returns the message
 */
function internalServerError() {
  return errorMessage("Internal Server Error");
}

export const ServerMessages = {
  baseMessage,
  errorMessage,
  successMessage,
  internalServerError,
};
